use serde::Deserialize;
use anyhow::Result;
use serde_json;

#[derive(Debug,Deserialize)]
pub struct Charger {
    pub id: String,
    pub channel_id: String,
    pub owners: Vec<String>,
}

#[derive(Debug,Deserialize)]
pub struct Mattermost {
    pub base: String,
    pub token: String,
}

#[derive(Debug,Deserialize)]
pub struct Prometheus {
    pub base: String
}

#[derive(Debug,Deserialize)]
pub struct Config {
    pub easee_token_path: String,
    pub prometheus: Prometheus,
    pub mattermost: Mattermost,
    pub chargers: Vec<Charger>,
    pub regulator: Option<Regulator>,
}

#[derive(Debug,Deserialize)]
pub struct Regulator {
    pub site_id: u32,
    pub circuit_id: i64,
    pub power_bias_watts: f64,
    pub monophase_volts: f64,
    pub polling_interval: u64,
    pub p: f64,
    pub i: f64,
    pub d: f64,
}

pub fn load_config(path: &str) -> Result<Config> {
    Ok(serde_json::from_str(&std::fs::read_to_string(path)?)?)
}